@@ -316,9 +316,10 @@ static zero_copy_if::sptr make_xport(
 /***********************************************************************
  * Structors
  **********************************************************************/
-usrp2_impl::usrp2_impl(const device_addr_t &_device_addr){
+usrp2_impl::usrp2_impl(const device_addr_t &_device_addr) :
+    device_addr(_device_addr)
+{
     UHD_MSG(status) << "Opening a USRP2/N-Series device..." << std::endl;
-    device_addr_t device_addr = _device_addr;
 
     //setup the dsp transport hints (default to a large recv buff)
     if (not device_addr.has_key("recv_buff_size")){
